@@ -286,11 +286,10 @@ def info(cli):
     return(result)
 
 
-@report.command()
+@report.command(deprecated=True)
 @pass_cli
 def crypto(cli):
-    click.echo('crypto is a deprecated endpoint and will be removed in future releases, please migrate to certificates and privatekeys',
-               err=True)
+    """deprecated (use certificates, public-keys, and private-keys)"""
     result = cli.do_GET(f'/api/report/crypto/{cli.ufid}', query_list=['sorters[0][field]=path',
                                                                       'sorters[0][dir]=asc'])
     cli.echo(result)
@@ -391,11 +390,20 @@ def binary_hardening(cli):
     return(result)
 
 
+@report.command(name='security-checklist')
+@pass_cli
+def security_checklist(cli):
+    result = cli.do_GET(f'/api/report/SecurityChecklist/{cli.ufid}', paginated=False)
+    cli.echo(result)
+    return(result)
+
+
 @report.command(name='check-policy')
 @click.option('--policy-yaml', metavar='FILE', type=click.Path(), help='Centrifuge policy yaml file.', required=True)
+@click.option('--report-template', metavar='FILE', type=click.Path(), help='Policy report template file.', required=False)
 @click.pass_context
 @pass_cli
-def check_policy(cli, ctx, policy_yaml):
+def check_policy(cli, ctx, policy_yaml, report_template):
     outfmt = cli.outfmt
     cli.outfmt = 'json'
     cli.echo_enabled = False
@@ -406,19 +414,26 @@ def check_policy(cli, ctx, policy_yaml):
     guardian_json = json.loads(ctx.invoke(guardian))
     code_summary_json = json.loads(ctx.invoke(code_summary))
     passhash_json = json.loads(ctx.invoke(passhash))
+    checklist_json = json.loads(ctx.invoke(security_checklist))
+    info_json = json.loads(ctx.invoke(info))
 
     policy_obj = CentrifugePolicyCheck(certificates_json,
                                        private_keys_json,
                                        binary_hardening_json,
                                        guardian_json,
                                        code_summary_json,
-                                       passhash_json)
+                                       passhash_json,
+                                       checklist_json,
+                                       info_json)
 
     policy_obj.check_rules(policy_yaml)
 
-    result = policy_obj.generate_csv()
-    if outfmt == 'json':
+    if report_template:
+        result = policy_obj.generate_report(report_template)
+    elif outfmt == 'json':
         result = policy_obj.generate_json()
+    else:
+        result = policy_obj.generate_csv()
 
     cli.echo_enabled = True
     cli.outfmt = outfmt
